<?php
/**
 * Ambition.
 *
 * Onboarding config to load plugins and homepage content on theme activation.
 *
 * @package Ambition
 * @author  Appfinite
 * @license GPL-2.0-or-later
 * @link    https://appfinite.com/
 */

 return [
	'dependencies'     => [
	 	'plugins'          => [
	 		[
	 			'name'       => __( 'Atomic Blocks', 'ambition' ),
	 			'slug'       => 'atomic-blocks/atomicblocks.php',
	 			'public_url' => 'https://atomicblocks.com/',
	 		],
	 		[
	 			'name'       => __( 'Simple Social Icons', 'ambition' ),
	 			'slug'       => 'simple-social-icons/simple-social-icons.php',
	 			'public_url' => 'https://wordpress.org/plugins/simple-social-icons/',
	 		],
	 		[
	 			'name'       => __( 'Genesis eNews Extended (Third Party)', 'ambition' ),
	 			'slug'       => 'genesis-enews-extended/plugin.php',
	 			'public_url' => 'https://wordpress.org/plugins/genesis-enews-extended/',
	 		],
	 		[
	 			'name'       => __( 'WPForms Lite (Third Party)', 'ambition' ),
	 			'slug'       => 'wpforms-lite/wpforms.php',
	 			'public_url' => 'https://wordpress.org/plugins/wpforms-lite/',
	 		],
	 	],
	],
 	'content'          => [
		'homepage'  => [
			'post_title'     => 'Homepage',
			'post_content'   => require dirname( __FILE__ ) . '/import/content/homepage.php',
			'post_type'      => 'page',
			'post_status'    => 'publish',
			'page_template'  => 'page-templates/blocks.php',
			'comment_status' => 'closed',
			'ping_status'    => 'closed',
			'meta_input'     => [ '_genesis_layout' => 'full-width-content' ],
		],
 		'blocks'  => [
 			'post_title'     => 'Block Content Examples',
 			'post_content'   => require dirname( __FILE__ ) . '/import/content/block-examples.php',
 			'post_type'      => 'page',
 			'post_status'    => 'publish',
 			'comment_status' => 'closed',
 			'ping_status'    => 'closed',
 			'meta_input'     => [ '_genesis_layout' => 'full-width-content' ],
 		],
 		'about'   => [
 			'post_title'     => 'About Us',
 			'post_content'   => require dirname( __FILE__ ) . '/import/content/about.php',
 			'post_type'      => 'page',
 			'post_status'    => 'publish',
 			'featured_image' => CHILD_URL . '/config/import/images/about.jpg',
 			'comment_status' => 'closed',
 			'ping_status'    => 'closed',
 			'meta_input'     => [
 				'_genesis_layout'              => 'full-width-content',
 				'_genesis_hide_singular_image' => true,
 			],
 		],
 		'contact' => [
 			'post_title'     => 'Contact Us',
 			'post_content'   => require dirname( __FILE__ ) . '/import/content/contact.php',
 			'post_type'      => 'page',
 			'post_status'    => 'publish',
 			'comment_status' => 'closed',
 			'ping_status'    => 'closed',
 		],
 		'landing' => [
 			'post_title'     => 'Landing Page',
 			'post_content'   => require dirname( __FILE__ ) . '/import/content/landing-page.php',
 			'post_type'      => 'page',
 			'post_status'    => 'publish',
 			'page_template'  => 'page-templates/landing.php',
 			'comment_status' => 'closed',
 			'ping_status'    => 'closed',
 			'meta_input'     => [
 				'_genesis_layout'              => 'full-width-content',
 				'_genesis_hide_breadcrumbs'    => true,
 				'_genesis_hide_singular_image' => true,
 				'_genesis_hide_footer_widgets' => true,
 			],
 		],
 	],
 	'navigation_menus' => [
 		'primary' => [
 			'homepage' => [
 				'title' => 'Home',
 			],
 			'about'    => [
 				'title' => 'About Us',
 			],
 			'contact'  => [
 				'title' => 'Contact Us',
 			],
 			'blocks'   => [
 				'title' => 'Block Examples',
 			],
 			'landing'  => [
 				'title' => 'Landing Page',
 			],
 		],
 	],
 	'widgets'          => [
 		'footer-1' => [
 			[
 				'type' => 'text',
 				'args' => [
 					'title'  => 'Design',
 					'text'   => '<p>With an emphasis on typography, white space, and mobile-optimized design, your website will look absolutely breathtaking.</p><p><a href="#">Learn more about design</a>.</p>',
 					'filter' => 1,
 					'visual' => 1,
 				],
 			],
 		],
 		'footer-2' => [
 			[
 				'type' => 'text',
 				'args' => [
 					'title'  => 'Content',
 					'text'   => '<p>Our team will teach you the art of writing audience-focused content that will help you achieve the success you truly deserve.</p><p><a href="#">Learn more about content</a>.</p>',
 					'filter' => 1,
 					'visual' => 1,
 				],
 			],
 		],
 		'footer-3' => [
 			[
 				'type' => 'text',
 				'args' => [
 					'title'  => 'Strategy',
 					'text'   => '<p>We help creative entrepreneurs build their digital business by focusing on three key elements of a successful online platform.</p><p><a href="#">Learn more about strategy</a>.</p>',
 					'filter' => 1,
 					'visual' => 1,
 				],
 			],
 		],
 	],
 ];
